<!DOCTYPE TS><TS>
<context>
    <name>EditMetadataDialog</name>
    <message>
        <source>Level %1</source>
        <translation>レベル %1</translation>
    </message>
    <message>
        <source>None</source>
        <translation>無し</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation type="obsolete">カバー無し</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>終了</translation>
    </message>
</context>
<context>
    <name>FileAssocDialog</name>
    <message>
        <source>Done</source>
        <translation>終了</translation>
    </message>
    <message>
        <source>New</source>
        <translation>新規</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Please enter the new extension:</source>
        <translation>新しい拡張子を入力してください:</translation>
    </message>
    <message>
        <source>Create new extension</source>
        <translation>新しい拡張子を作る</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds videos</source>
        <translation>ビデオを保存するディレクトリ</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythVideo only needs to have read permission to the directory.</source>
        <translation>このディレクトリは必ず存在しなければなりません.そしてMythVideoを実行するユーザーに書き込み権限が必要です.</translation>
    </message>
    <message>
        <source>Starting Parental Level</source>
        <translation>再生制限レベル</translation>
    </message>
    <message>
        <source>4 - Highest</source>
        <translation>4 - 高</translation>
    </message>
    <message>
        <source>1 - Lowest</source>
        <translation>1 - 低</translation>
    </message>
    <message>
        <source>This is the &apos;level&apos; that MythVideo starts at. Any videos with a level at or below this will be shown in the list or while browsing by default. The Parental PIN should be set to limit changing of the default level.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parental Control PIN</source>
        <translation>再生制限制御ピン</translation>
    </message>
    <message>
        <source>If set, you will not be able to return to this screen and reset the Parental PIN without first entering the current PIN. You have been warned.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Unknown File Types</source>
        <translation>不明なファイルタイプを表示する</translation>
    </message>
    <message>
        <source>If set, all files below the Myth Video directory will be displayed unless their extension is explicitly set to be ignored. </source>
        <translation>これをセットするとMythVideoのディレクトリにある無視すると指定された拡張子を除く全てのファイルを表示します.</translation>
    </message>
    <message>
        <source>Video List browses files</source>
        <translation>見えるファイルを表示する</translation>
    </message>
    <message>
        <source>If set, this will cause the Video List screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
        <translation>これをセットすると、MythVideoの開始ディレクトリで関連の有るファイルをスキャンされてなくても表示します。</translation>
    </message>
    <message>
        <source>Player Settings</source>
        <translation>プレイヤー設定</translation>
    </message>
    <message>
        <source>Parental Pin:</source>
        <translation type="obsolete">再生制限ピン:</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation type="obsolete">カバー無し</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>不明</translation>
    </message>
    <message>
        <source>None</source>
        <translation>無し</translation>
    </message>
    <message>
        <source>Unknown Rating</source>
        <translation type="obsolete">不明なレイティング</translation>
    </message>
    <message>
        <source>Default Player</source>
        <translation>既定のプレイヤー</translation>
    </message>
    <message>
        <source>Newly scanned files are browsable by default</source>
        <translation>新しく検索されたファイルを表示する</translation>
    </message>
    <message>
        <source>If set, newly scanned files in the Video Manager will be marked as browsable and will appear in the &apos;Browse&apos; menu.</source>
        <translation>新しく検索されたファイルをビデオマネージャーで表示可能のマークをつける。</translation>
    </message>
    <message>
        <source>New category</source>
        <translation>新カテゴリー</translation>
    </message>
    <message>
        <source>This PIN is used to control the current Parental Level. If you want to use this feature, then setting the value to all numbers will make your life much easier.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command to search for movie listings</source>
        <translation>映画リストの検索コマンド</translation>
    </message>
    <message>
        <source>This command must be executable by the user running MythVideo.</source>
        <translation>MythVideoの実行ユーザーが実行できるコマンドを指定してください。</translation>
    </message>
    <message>
        <source>Command to search for movie posters</source>
        <translation>映画ポスターを探すコマンド</translation>
    </message>
    <message>
        <source>Command to extract data for movies</source>
        <translation>映画データの解凍コマンド</translation>
    </message>
    <message>
        <source>Directory that holds movie posters</source>
        <translation>映画ポスターを保存するディレクトリ</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythVideo needs to have read/write permission to the directory.</source>
        <translation>このディレクトリは必ず存在しなければなりません.そしてMythVideoを実行するユーザーに書き込み権限が必要です.</translation>
    </message>
    <message>
        <source>Video Manager</source>
        <translation>ビデオマネージャ</translation>
    </message>
    <message>
        <source>Could not retrieve poster</source>
        <translation>ポスターを検索できませんでした</translation>
    </message>
    <message>
        <source>A movie poster exists for this movie but Myth could not retrieve it within a reasonable amount of time.
</source>
        <translation>この映画のポスターは存在しますがMythTVは時間内に検索できませんでした。
</translation>
    </message>
    <message>
        <source>Default View</source>
        <translation>規定のビュー</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>ギャラリー</translation>
    </message>
    <message>
        <source>Browser</source>
        <translation>ブラウザ</translation>
    </message>
    <message>
        <source>Listings</source>
        <translation>リスト</translation>
    </message>
    <message>
        <source>Aggressive Parental Control</source>
        <translation>積極的な再生制御</translation>
    </message>
    <message>
        <source>This is the command used for any file that the extension is not specifically defined. You may also enter the name of one of the playback plugins such as &apos;Internal&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rows to display</source>
        <translation>表示行</translation>
    </message>
    <message>
        <source>Columns to display</source>
        <translation>表示列</translation>
    </message>
    <message>
        <source>Show title below thumbnails</source>
        <translation>サムネイルのしたにタイトルを表示</translation>
    </message>
    <message>
        <source>If set, the additional text will make the thumbnails smaller.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maintain aspect ratio of thumbnails</source>
        <translation>サムネイルのアスペクトレシオを保持する</translation>
    </message>
    <message>
        <source>If set, the scaled thumbnails will maintain their original aspect ratio. If not set, they are scaled to match the size of the background icon.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Gallery</source>
        <translation>ビデオギャラリー</translation>
    </message>
    <message>
        <source>The default view for MythVideo. Other views can be reached via the popup menu available via the MENU key.</source>
        <translation>MythVideoのデフォルトビュー。他のビューはMENUキーを押して出るポップアップから選択できます。</translation>
    </message>
    <message>
        <source>Video Browser browses files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, this will cause the Video Browser screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Gallery browses files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, this will cause the Video Gallery screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General Settings (1/2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General Settings (2/2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video List Loads Video Meta Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set along with Browse Files, this will cause the Video List to load any known video metadata from the database. Turning this off can greatly  speed up how long it takes to load the Video List tree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sorting ignores case</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, case is ignored when sorting entries in a view.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show folders for database views</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, sub folders of your video directory will be shown in supported views.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image cache size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This setting determines the number of images MythVideo will cache for views.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>^(The |A |An )</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished">全て</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished">はい</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished">いいえ</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Year</source>
        <translation type="unfinished">年</translation>
    </message>
    <message>
        <source>User Rating</source>
        <translation type="unfinished">ユーザー格付け</translation>
    </message>
    <message>
        <source>Runtime</source>
        <translation type="unfinished">所用時間</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video ID</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Director:</source>
        <translation>ディレクター:</translation>
    </message>
    <message>
        <source>Year:</source>
        <translation>年:</translation>
    </message>
    <message>
        <source>Rated:</source>
        <translation>定格:</translation>
    </message>
    <message>
        <source>Parental Level:</source>
        <translation>再生制限レベル:</translation>
    </message>
    <message>
        <source>Browsable:</source>
        <translation>表示:</translation>
    </message>
    <message>
        <source>Runtime:</source>
        <translation>時間:</translation>
    </message>
    <message>
        <source>Plot:</source>
        <translation>荒筋:</translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation>ファイル名:</translation>
    </message>
    <message>
        <source>Cover File:</source>
        <translation>カバーファイル:</translation>
    </message>
    <message>
        <source>IMDB Num.:</source>
        <translation>IMDB番号:</translation>
    </message>
    <message>
        <source>retrieving data...</source>
        <translation>データ取得中...</translation>
    </message>
    <message>
        <source>[ looking for ]</source>
        <translation>[ 検索中 ]</translation>
    </message>
    <message>
        <source>Enter IMDB #</source>
        <translation>IMDB番号入力</translation>
    </message>
    <message>
        <source>loading...</source>
        <translation>読込中...</translation>
    </message>
    <message>
        <source>No Videos Found</source>
        <translation>ビデオファイルを削除できませんでした</translation>
    </message>
    <message>
        <source>Directed by</source>
        <translation>監督</translation>
    </message>
    <message>
        <source>File:</source>
        <translation>ファイル:</translation>
    </message>
    <message>
        <source>Player:</source>
        <translation>プレイヤー:</translation>
    </message>
    <message>
        <source>MythVideo File Associations</source>
        <translation>MythVideo ファイル関連付け</translation>
    </message>
    <message>
        <source>Extension:</source>
        <translation>拡張子:</translation>
    </message>
    <message>
        <source>Command:</source>
        <translation>コマンド:</translation>
    </message>
    <message>
        <source>Use default player:</source>
        <translation>既定のプレイヤー:</translation>
    </message>
    <message>
        <source>Ignore:</source>
        <translation>無視:</translation>
    </message>
    <message>
        <source>Edit Video Information</source>
        <translation>ビデオ情報編集</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>名前:</translation>
    </message>
    <message>
        <source>Parental Control:</source>
        <translation>再生制限:</translation>
    </message>
    <message>
        <source>File to Always Play Next:</source>
        <translation>いつも次を再生する:</translation>
    </message>
    <message>
        <source>Include while Browsing:</source>
        <translation>表示する:</translation>
    </message>
    <message>
        <source>Cover Art:</source>
        <translation>カバー絵:</translation>
    </message>
    <message>
        <source>Unique Player Command:</source>
        <translation>固有のプレイヤーコマンド:</translation>
    </message>
    <message>
        <source>1</source>
        <translation></translation>
    </message>
    <message>
        <source>PL </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>/path/to/the/thing.jpg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>カテゴリー:</translation>
    </message>
    <message>
        <source>Filters video list</source>
        <translation>ビデオリスト絞りこみ</translation>
    </message>
    <message>
        <source>Category :</source>
        <translation>カテゴリー:</translation>
    </message>
    <message>
        <source>Genre :</source>
        <translation>ジャンル:</translation>
    </message>
    <message>
        <source>Country :</source>
        <translation>国:</translation>
    </message>
    <message>
        <source>Year :</source>
        <translation>年:</translation>
    </message>
    <message>
        <source>Runtime :</source>
        <translation>所用時間:</translation>
    </message>
    <message>
        <source>User Rating :</source>
        <translation>ユーザー格付:</translation>
    </message>
    <message>
        <source>Browse :</source>
        <translation>表示:</translation>
    </message>
    <message>
        <source>Sort by :</source>
        <translation>並び換え:</translation>
    </message>
    <message>
        <source>Aucune video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SELECT: Edit</source>
        <translation>選択: 編集</translation>
    </message>
    <message>
        <source></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parental</source>
        <translation>再生制限</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>レベル</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>年</translation>
    </message>
    <message>
        <source>Runtime</source>
        <translation>所用時間</translation>
    </message>
    <message>
        <source>User Rating</source>
        <translation>ユーザー格付け</translation>
    </message>
    <message>
        <source>INFO - Action Menu</source>
        <translation>INFO - アクションメニュー</translation>
    </message>
    <message>
        <source>Up/Down, Page Up/Down: Browse   MENU: Options   INFO: Action Menu</source>
        <translation>Up/Down, Page Up/Down: 移動   MENU: オプション   INFO: アクションメニュー</translation>
    </message>
    <message>
        <source>Play File After This:</source>
        <translation>このファイルの後に再生:</translation>
    </message>
</context>
<context>
    <name>VideoBrowser</name>
    <message>
        <source>%1 of %2</source>
        <translation>%1 / %2</translation>
    </message>
    <message>
        <source>No Videos</source>
        <translation>ビデオ無し</translation>
    </message>
    <message>
        <source>No rating available.</source>
        <translation type="obsolete">レイティングは使用できません.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="obsolete">分</translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation>このビデオを見る</translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation>全ての粗筋を表示する</translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation>表示絞りこみ</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
</context>
<context>
    <name>VideoDialog</name>
    <message>
        <source>Switch to Browse View</source>
        <translation>ブラウズビューに切替え</translation>
    </message>
    <message>
        <source>Switch to Gallery View</source>
        <translation>ギャラリービューに切替え</translation>
    </message>
    <message>
        <source>Switch to List View</source>
        <translation>リストビューに切替え</translation>
    </message>
    <message>
        <source>Select action</source>
        <translation>動作選択</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>はい</translation>
    </message>
    <message>
        <source>Parental Pin:</source>
        <translation type="obsolete">再生制限ピン:</translation>
    </message>
</context>
<context>
    <name>VideoFilterDialog</name>
    <message>
        <source>Result of this filter : %1 video(s)</source>
        <translation>このフィルタの結果 : %1 個</translation>
    </message>
    <message>
        <source>Result of this filter : No Videos</source>
        <translation>このフィルタの結果 : 該当無し</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">不明</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>分</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="obsolete">全て</translation>
    </message>
    <message>
        <source>Save as default</source>
        <translation>規定で保存</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>終了</translation>
    </message>
</context>
<context>
    <name>VideoGallery</name>
    <message>
        <source>Filter Display</source>
        <translation>絞りこみ表示</translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation>このビデオを見る</translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation>全ての粗筋を表示する</translation>
    </message>
    <message>
        <source>View Details</source>
        <translation>詳細を表示する</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
</context>
<context>
    <name>VideoManager</name>
    <message>
        <source>Manually Enter IMDB #</source>
        <translation>IMDB番号を入力する</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="obsolete">分</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="obsolete">はい</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="obsolete">いいえ</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation type="obsolete">カバー無し</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">不明</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">無し</translation>
    </message>
    <message>
        <source>delete failed</source>
        <translation>削除失敗</translation>
    </message>
    <message>
        <source>Select action:</source>
        <translation>動作選択:</translation>
    </message>
    <message>
        <source>Edit Metadata</source>
        <translation>メタデータ編集</translation>
    </message>
    <message>
        <source>Search IMDB</source>
        <translation>IMDB検索</translation>
    </message>
    <message>
        <source>Reset Metadata</source>
        <translation>メタデータリセット</translation>
    </message>
    <message>
        <source>Toggle Browseable</source>
        <translation>表示切替え</translation>
    </message>
    <message>
        <source>Remove Video</source>
        <translation>ビデオ削除</translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation>表示絞りこみ</translation>
    </message>
    <message>
        <source>Delete this file?</source>
        <translation>このファイルを削除しますか?</translation>
    </message>
</context>
<context>
    <name>VideoSelected</name>
    <message>
        <source>No rating available.</source>
        <translation type="obsolete">レイティングは使用できません.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="obsolete">分</translation>
    </message>
</context>
<context>
    <name>VideoTree</name>
    <message>
        <source>Parental Pin:</source>
        <translation type="obsolete">再生制限ピン:</translation>
    </message>
    <message>
        <source>Select action</source>
        <translation>動作選択</translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation>このビデオを見る</translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation>全ての粗筋を表示する</translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation>絞りこみ表示</translation>
    </message>
    <message>
        <source>Switch to Browse View</source>
        <translation>ブラウズビューに切替え</translation>
    </message>
    <message>
        <source>Switch to Gallery View</source>
        <translation>ギャラリービューに切替え</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>はい</translation>
    </message>
</context>
</TS>
